@@ -7,7 +7,7 @@ use Carp;
 use Moo;
 use namespace::clean;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 with qw( CLDR::Number::Role::Format );
 
@@ -53,15 +53,8 @@ CLDR::Number::Format::Decimal - Localized decimal formatter using the Unicode CL
 
 =head1 VERSION
 
-This document describes CLDR::Number::Format::Decimal v0.10, built with Unicode
-CLDR v24.
-
-=head1 DEPRECATION
-
-Using the C<locale> method as a setter is deprecated. In the future the object’s
-locale will become immutable. Please see
-L<issue #38|https://github.com/perl-cldr/cldr-number-pm5/issues/38> for details
-and to submit comments or concerns.
+This document describes CLDR::Number::Format::Decimal v0.11, built with Unicode
+CLDR v27.0.1.
 
 =head1 SYNOPSIS
 
@@ -75,7 +68,7 @@ and to submit comments or concerns.
     $decf = $cldr->decimal_formatter;
 
     # when locale is 'es' (Spanish)
-    say $decf->format(1234.5);  # '1 234,5'
+    say $decf->format(1234.5);  # '1.234,5'
 
     # when locale is 'es-MX' (Mexican Spanish)
     say $decf->format(1234.5);  # '1,234.5'
@@ -86,6 +79,13 @@ and to submit comments or concerns.
     # when locale is 'bn' (Bengali)
     say $curf->format(123456);  # '১,২৩,৪৫৬'
 
+=head1 DEPRECATION
+
+Using the C<locale> method as a setter is deprecated. In the future the object’s
+locale will become immutable. Please see
+L<issue #38|https://github.com/patch/cldr-number-pm5/issues/38> for details and
+to submit comments or concerns.
+
 =head1 DESCRIPTION
 
 Localized decimal formatter using the Unicode Common Locale Data Repository
@@ -181,11 +181,10 @@ L<CLDR::Number>
 
 =head1 AUTHOR
 
-Nick Patch <patch@cpan.org>
+Nova Patch <patch@cpan.org>
 
-This project is brought to you by L<Perl CLDR|http://perl-cldr.github.io/> and
-L<Shutterstock|http://www.shutterstock.com/>. Additional open source projects
-from Shutterstock can be found at
+This project is brought to you by L<Shutterstock|http://www.shutterstock.com/>.
+Additional open source projects from Shutterstock can be found at
 L<code.shutterstock.com|http://code.shutterstock.com/>.
 
 =head1 COPYRIGHT AND LICENSE
