@@ -12,7 +12,7 @@ use Moo::Role;
 # backward incompatible ways in the future. Please use one of the documented
 # classes instead.
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 requires qw( BUILD );
 
@@ -23,7 +23,7 @@ has version => (
 
 has cldr_version => (
     is      => 'ro',
-    default => 24,
+    default => $CLDR::Number::Data::Base::CLDR_VERSION,
 );
 
 has locale => (
